summaryrefslogtreecommitdiff
path: root/include/LibreOfficeKit/LibreOfficeKit.h
diff options
context:
space:
mode:
authorPranav Kant <pranavk@collabora.co.uk>2017-12-01 14:27:21 +0530
committerPranav Kant <pranavk@collabora.co.uk>2017-12-04 17:14:03 +0530
commitb1bcc70d2a5a51d2cb4b2e9e2a8e6641719fe18b (patch)
tree0347b8a69436f99c889b57b9072fc34fffaaea63 /include/LibreOfficeKit/LibreOfficeKit.h
parentae412b57e3f7866e24b120f0afb8ac80618a8d07 (diff)
lokdialog: Merge dialog & dialog child mouse event APIs into one
Change-Id: I91aaa6a58f33dd2d817e02533de96e0c8191f2ca
Diffstat (limited to 'include/LibreOfficeKit/LibreOfficeKit.h')
-rw-r--r--include/LibreOfficeKit/LibreOfficeKit.h20
1 files changed, 5 insertions, 15 deletions
diff --git a/include/LibreOfficeKit/LibreOfficeKit.h b/include/LibreOfficeKit/LibreOfficeKit.h
index 8db531650dbf..f9c9e22a730e 100644
--- a/include/LibreOfficeKit/LibreOfficeKit.h
+++ b/include/LibreOfficeKit/LibreOfficeKit.h
@@ -270,7 +270,7 @@ struct _LibreOfficeKitDocumentClass
int* pArray,
size_t nSize);
/// Paints dialog with given dialog id to the buffer
/// @see lok::Document::paintWindow().
void (*paintWindow) (LibreOfficeKitDocument* pThis, unsigned nWindowId,
unsigned char* pBuffer,
@@ -282,14 +282,14 @@ struct _LibreOfficeKitDocumentClass
/// @see lok::Document::postWindowKeyEvent().
void (*postWindowKeyEvent) (LibreOfficeKitDocument* pThis,
- unsigned nDialogId,
+ unsigned nWindowId,
int nType,
int nCharCode,
int nKeyCode);
- /// @see lok::Document::postDialogMouseEvent().
- void (*postDialogMouseEvent) (LibreOfficeKitDocument* pThis,
- unsigned nDialogId,
+ /// @see lok::Document::postWindowMouseEvent().
+ void (*postWindowMouseEvent) (LibreOfficeKitDocument* pThis,
+ unsigned nWindowId,
int nType,
int nX,
int nY,
@@ -297,16 +297,6 @@ struct _LibreOfficeKitDocumentClass
int nButtons,
int nModifier);
- /// @see lok::Document::postDialogChildMouseEvent().
- void (*postDialogChildMouseEvent) (LibreOfficeKitDocument* pThis,
- unsigned nDialogId,
- int nType,
- int nX,
- int nY,
- int nCount,
- int nButtons,
- int nModifier);
-
#endif // defined LOK_USE_UNSTABLE_API || defined LIBO_INTERNAL_ONLY
};
@@ -270,7 +270,7 @@ struct _LibreOfficeKitDocumentClass
int* pArray,
size_t nSize);
- /// Paints dialog with given dialog id to the buffer
+ /// Paints window with given id to the buffer
/// @see lok::Document::paintWindow().
void (*paintWindow) (LibreOfficeKitDocument* pThis, unsigned nWindowId,